@@ -23,16 +23,16 @@
 #include "audiomanager.h"
 #include "database.h"
 #include "datamanager.h"
-#include "enclosuredownloadjob.h"
 #include "entry.h"
 #include "error.h"
 #include "fetcher.h"
 #include "models/downloadmodel.h"
 #include "models/errorlogmodel.h"
-#include "networkconnectionmanager.h"
 #include "settingsmanager.h"
-#include "storagemanager.h"
 #include "sync/sync.h"
+#include "utils/enclosuredownloadjob.h"
+#include "utils/networkconnectionmanager.h"
+#include "utils/storagemanager.h"
 
 Enclosure::Enclosure(Entry *entry)
     : QObject(entry)
@@ -156,13 +156,18 @@ void Enclosure::download()
     }
 
     if (!NetworkConnectionManager::instance().episodeDownloadsAllowed()) {
-        Q_EMIT downloadError(Error::Type::MeteredNotAllowed,
-                             m_entry->feed()->url(),
-                             m_entry->id(),
-                             0,
-                             i18n("Podcast downloads not allowed due to user setting"),
-                             QString());
-        return;
+        if (NetworkConnectionManager::instance().networkReachable()) {
+            Q_EMIT downloadError(Error::Type::MeteredNotAllowed,
+                                 m_entry->feed()->url(),
+                                 m_entry->id(),
+                                 0,
+                                 i18n("Podcast downloads not allowed on metered connection"),
+                                 QString());
+            return;
+        } else {
+            Q_EMIT downloadError(Error::Type::NoNetwork, m_entry->feed()->url(), m_entry->id(), 0, i18n("No network connection"), QString());
+            return;
+        }
     }
 
     checkSizeOnDisk();
