@@ -20,22 +20,15 @@
 #include <KFormat>
 #include <KLocalizedString>
 
-#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
 #include <qt6keychain/keychain.h>
-#else
-#include <qt5keychain/keychain.h>
-#endif
 
 #include "audiomanager.h"
 #include "database.h"
 #include "datamanager.h"
 #include "entry.h"
 #include "fetcher.h"
-#include "fetchfeedsjob.h"
 #include "models/errorlogmodel.h"
-#include "networkconnectionmanager.h"
 #include "settingsmanager.h"
-#include "storagemanager.h"
 #include "sync/gpodder/devicerequest.h"
 #include "sync/gpodder/episodeactionrequest.h"
 #include "sync/gpodder/gpodder.h"
@@ -48,6 +41,9 @@
 #include "sync/gpodder/uploadsubscriptionrequest.h"
 #include "sync/syncjob.h"
 #include "sync/syncutils.h"
+#include "utils/fetchfeedsjob.h"
+#include "utils/networkconnectionmanager.h"
+#include "utils/storagemanager.h"
 
 using namespace SyncUtils;
 
